ChangepointDetector
=================================================

This object can be used to detect changepoints in a time series using the CUSUMDetector.detector() and BOCPDetector.detector() functions from kats. This object is new as of dist 0.12.6. See the helpful `tutorial <https://github.com/facebookresearch/Kats/blob/main/tutorials/kats_202_detection.ipynb>`_ developed by the creators of Kats. The functions are left unadjusted in this object and are only adapted to interface with the Forecaster object from scalecast.

.. autoclass:: src.scalecast.ChangepointDetector.ChangepointDetector
   :members: